@@ -1,4 +1,7 @@
-#!/bin/bash -e
+#!/usr/bin/env bash
+
+set -e
+set -o pipefail
 
 get_machine_arch () {
     machine_arch=""
